#!/bin/bash
#
# Author: Honza Horak <hhorak@redhat.com>
#
# This is a simple tool to generate mock config file for building
# SCL packages in it.
#
# License: Public Domain

usage() {
    echo "Usage: `basename $1` sclname [ -r repodir ] [ -s sourcemock ] [ -o outputdir ]"
    exit $2
}

if [ $# -lt 1 ] ; then
    usage "$0" 1
fi

sclname=$1
shift
mockfullname="scl-${sclname}"
repodir=/home/$(whoami)/$mockfullname
def=$(readlink -f /etc/mock/default.cfg)
mocksource=$(basename $def | sed -e 's/\.cfg//')
outputdir=$(pwd)

while [ -n "$1" ] ; do
    param="$1"
    shift
    case "$param" in
        "-h" )
             usage "$0" 0
             ;;
        "-s" )
             [ -z "$1" ] && usage "$0" 1
             mocksource="$1"
             shift
             ;;
        "-r" )
             [ -z "$1" ] && usage "$0" 1
             repodir=$(readlink -f $1)
             shift ;;
        "-o" )
             [ -z "$1" ] && usage "$0" 1
             outputdir=$(readlink -f $1)
             shift ;;
        *) usage "$0" 1 ;;
     esac
done

echo "Creating mock config for collection $sclname"
echo "Using mock config /etc/mock/$mocksource as a source"
echo "Using repository from $repodir"
echo "Storing output into $outputdir"

origmockfile="/etc/mock/${mocksource}.cfg"
if ! [ -f "$origmockfile" ] ; then
    echo "Mock config file $mocksource does not exist."
    exit 1
fi

if ! [ -d "$outputdir" ] ; then
    mkdir -p $outputdir
fi

if ! [ -d "$repodir" ] ; then
    mkdir -p $repodir
fi
createrepo $repodir

tmpcoprrepofile=$(mktemp /tmp/tmprepocoprfileXXXXXXX)
cat >$tmpcoprrepofile <<EOF
[localscl-$sclname]
name=local scl $sclname
baseurl=file://$repodir
enabled=1
gpgcheck=0
EOF

newmockname="${mockfullname}-${mocksource}.cfg"
newmockfile="${outputdir}/${newmockname}"
grep -v -e '^"""' $origmockfile | sed -e "s/@buildsys-build/@buildsys-build scl-utils-build $sclname-build/g" >"$newmockfile"
echo >>"$newmockfile"
cat $tmpcoprrepofile >>"$newmockfile"
echo '"""' >>"$newmockfile"

echo "New mock config $newmockfile generated."

